# CALCOS

[![Jenkins CI](https://ssbjenkins.stsci.edu/job/STScI/job/calcos/job/master/badge/icon)](https://ssbjenkins.stsci.edu/job/STScI/job/calcos/job/master/)

Calibration software for HST/COS.

Nightly regression test results are available only from within the STScI
network at this time.
https://plwishmaster.stsci.edu:8081/job/RT/job/calcos/test_results_analyzer/
